@@ -10,6 +10,7 @@ import re
 import urllib.request
 import zipfile
 from pathlib import Path
+from typing import Optional
 
 import numpy as np
 
@@ -27,19 +28,20 @@ def unzip(file_path: str, dest_dir: str):
         zf.extractall(dest_dir)
 
 
-def save_json(data, save_path):
+def save_json(data, save_path, indent: Optional[int] = None):
     """
     Saves json formatted data (given as "data") as save_path
     Example inputs:
         data: {"image_id": 5}
         save_path: "dirname/coco.json"
+        indent: Train json files with indent=None, val json files with indent=4
     """
     # create dir if not present
     Path(save_path).parent.mkdir(parents=True, exist_ok=True)
 
     # export as json
     with open(save_path, "w", encoding="utf-8") as outfile:
-        json.dump(data, outfile, separators=(",", ":"), cls=NumpyEncoder)
+        json.dump(data, outfile, separators=(",", ":"), cls=NumpyEncoder, indent=indent)
 
 
 # type check when save json files
